@@ -27,7 +27,7 @@ sub get_init_script {
     my $layout    = shift;
     our $initsource;
     if(!defined $initsource) {
-       while(my $line = <DATA>) { $initsource .= $line; }
+       $initsource = do { local $/; <DATA> };
     }
 
     my $initscript = $initsource;
